@@ -31,6 +31,9 @@ class ServerProtocol(asyncio.Protocol):
         self.transport = transport
 
     def data_received(self, data):
+        if data == b"end":
+            self.transport.close()
+            return
         mtype = data[0]
         try:
             if mtype in MESSAGE_PROTOCOL:
@@ -55,9 +58,14 @@ class ServerProtocol(asyncio.Protocol):
         except Exception as e:
             logger.error(e)
             self.transport.write(e.__str__().encode("utf8"))
-        finally:
-            logger.info("Close the client socket")
-            self.transport.close()
+
+    def connection_lost(self, error):
+        self.transport.close()
+        if error:
+            logger.error('SERVER ERROR: {}'.format(error))
+        else:
+            logger.info('Client Closed')
+        super().connection_lost(error)
 
 
 class EchoServer:
@@ -75,9 +83,12 @@ class EchoServer:
         server = await loop.create_unix_server(
             lambda: ServerProtocol(self.ins, **self.kwargs), self.path,
         )
-
         async with server:
             await server.serve_forever()
 
     def run(self):
         asyncio.run(self.task())
+
+
+m = EchoServer("../unix_sock.sock")
+m.run()
